package com.ym.mec.web.controller;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.web.dal.entity.CourseSchedule;
import com.ym.mec.web.dal.page.StudentAttendanceQueryInfo;
import com.ym.mec.web.service.CourseScheduleService;
import com.ym.mec.web.service.StudentAttendanceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

/**
 * @Author Joburgess
 * @Date 2019/9/10
 */
@RequestMapping("courseSchedule")
@Api(tags = "课程计划服务")
@RestController
public class CourseScheduleController extends BaseController {

    @Autowired
    private CourseScheduleService scheduleService;
    @Autowired
    private StudentAttendanceService studentAttendanceService;

    @ApiOperation(value = "排课")
    @PostMapping("/batchAddCourseSchedule/{musicGroupID}")
    public Object batchAddCourseSchedule(@RequestBody List<CourseSchedule> courseSchedules,
                                         @ApiParam(value = "乐团编号", required = true) @PathVariable("musicGroupID") Long musicGroupID){
        String s = scheduleService.batchAddCourseSchedule(courseSchedules);
        if(s.isEmpty()){
            return succeed();
        }else{
            return failed(s);
        }
    }

    @ApiOperation(value = "批量跟新排课")
    @PostMapping("/batchUpdateCourseSchedule/{musicGroupID}")
    public Object batchUpdateCourseSchedule(@RequestBody List<CourseSchedule> courseSchedules,
                                            @ApiParam(value = "乐团编号", required = true) @PathVariable("musicGroupID") Long musicGroupID){
        String s = scheduleService.batchUpdateCourseSchedule(courseSchedules,musicGroupID);
        if(s.isEmpty()){
            return succeed();
        }else{
            return failed(s);
        }
    }

    @ApiOperation(value = "根据月份获取乐团在该月有课的日期")
    @GetMapping("/getCourseScheduleDateByMonth")
        public Object getCourseScheduleDateByMonth(@ApiParam(value = "乐团编号", required = true) @RequestParam Long musicGroupID,
                                                   @ApiParam(value = "月份", required = true) @RequestParam Date month) {
        return succeed(scheduleService.getCourseScheduleDateByMonth(musicGroupID,month));
    }

    @ApiOperation(value = "根据日期获取当日排课")
    @GetMapping("/getCourseSchedulesWithDate")
    public Object getCourseSchedulesWithDate(@ApiParam(value = "日期", required = true) Date date){
        return succeed(scheduleService.getCourseSchedulesWithDate(date));
    }

    @ApiOperation(value = "根据课程ID查询正在或即将开始的课程")
    @GetMapping("/getCurrentCourseDetail/{courseID}")
    public Object getCurrentCourseDetail(@ApiParam(value = "课程ID", required = true) @PathVariable("courseID") Long courseID){
        return succeed(scheduleService.getCurrentCourseDetail(courseID));
    }

    @ApiOperation(value = "根据班级ID获取当前课程的学生")
    @GetMapping("/getCurrentCourseStudents")
    public Object getCurrentCourseStudents(@RequestBody StudentAttendanceQueryInfo queryInfo){
        return succeed(studentAttendanceService.getCurrentCourseStudents(queryInfo));
    }

}
