package com.ym.mec.web.controller;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.common.page.QueryInfo;
import com.ym.mec.web.dal.entity.Teacher;
import com.ym.mec.web.dal.page.TeacherCourseQueryInfo;
import com.ym.mec.web.dal.page.TeacherQueryInfo;
import com.ym.mec.web.service.ClassGroupService;
import com.ym.mec.web.service.TeacherService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@RequestMapping("teacher")
@Api(tags = "教师服务")
@RestController
public class TeacherController extends BaseController {

    @Autowired
    private TeacherService teacherService;

    @Autowired
    private ClassGroupService classGroupService;

    @ApiOperation(value = "新增教师")
    @PostMapping("/add")
    public Object add(Teacher teacher) {
        try {
            teacherService.add(teacher);
        } catch (Exception e) {
            e.printStackTrace();
            return failed(e.getMessage());
        }
        return succeed();
    }

    @ApiOperation(value = "修改教师")
    @PostMapping("/update")
    public Object update(Teacher teacher) {
        teacher.setUpdateTime(new Date());
        teacherService.updateTea(teacher);
        return succeed();
    }

    @ApiOperation(value = "根据教师编号查询教师基本信息")
    @GetMapping("/get/{id}")
    @ApiParam(value = "教师编号", required = true)
    public Object get(@PathVariable("id") Integer id) {
        return succeed(teacherService.getDetail(id));
    }

    @ApiOperation(value = "分页查询教师列表")
    @GetMapping("/queryPage")
    public Object queryPage(TeacherQueryInfo queryInfo) {
        return succeed(teacherService.queryPageDetail(queryInfo));
    }

    @ApiOperation(value = "根据教师编号查询教师课程班列表")
    @GetMapping("/getClass/{id}")
    @ApiParam(value = "教师编号", required = true)
    public Object getClassGroup(@PathVariable("id") Integer id) {
        return succeed(classGroupService.findClassGroup4Teacher(id));
    }

    @ApiOperation(value = "获取老师课程信息列表")
    @GetMapping("/getTeaCourseInfos")
    public Object getTeaCourseInfos(QueryInfo queryInfo){
        return succeed(classGroupService.getTeaCourseInfos(queryInfo));
    }
}
