package com.ym.mec.web.controller.system;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.web.dal.page.StudentManageAttendanceQueryInfo;
import com.ym.mec.web.dal.page.StudentManageCourseQueryInfo;
import com.ym.mec.web.dal.page.StudentManageQueryInfo;
import com.ym.mec.web.service.StudentManageService;
import com.ym.mec.web.service.SysUserCashAccountService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Author Joburgess
 * @Date 2019/9/19
 */
@Api("学生管理")
@RequestMapping("studentManage")
@RestController
public class StudentManageController extends BaseController {

    @Autowired
    private StudentManageService studentManageService;

    @Autowired
    private SysUserCashAccountService sysUserCashAccountService;

    @ApiOperation(value = "获取学生列表")
    @GetMapping("/queryStudentList")
    public Object queryStudentList(@RequestBody StudentManageQueryInfo queryInfo){
        return succeed(studentManageService.findStudentsByOrganId(queryInfo));
    }

    @ApiOperation(value = "根据学生ID获取学生基本报名信息")
    @GetMapping("/findStudentBaseInfo")
    public Object findStudentBaseInfo(@ApiParam(value = "学生编号", required = true) @RequestParam Long userID){
        return succeed(studentManageService.findStudentManageBaseInfo(userID));
    }

    @ApiOperation(value = "根据学生ID获取其所在的乐团")
    @GetMapping("/findStudentMusicGroups/{userID}")
    public Object findStudentMusicGroups(@ApiParam(value = "学生编号", required = true) @PathVariable("userID") Long userID){
        return succeed(studentManageService.findStudentMusicGroupsByUserId(userID));
    }

    @ApiOperation(value = "根据乐团获取排课列表")
    @PostMapping("/findStudentCourses")
    public Object findStudentCourses(@RequestBody StudentManageCourseQueryInfo queryInfo){
        return succeed(studentManageService.findStudentCourseList(queryInfo));
    }

    @ApiOperation(value = "获取学生签到列表")
    @PostMapping("/findStudentAttendances")
    public Object findStudentAttendances(@RequestBody StudentManageAttendanceQueryInfo queryInfo){
        return succeed(studentManageService.findStudentAttendances(queryInfo));
    }

    @ApiOperation(value = "获取学生vip课")
    @PostMapping("/findStudentVipGroups")
    public Object findStudentVipGroups(Long userId){
        return succeed(studentManageService.findStudentVipGroups(userId));
    }

    @ApiOperation(value = "获取用户默认账户基本信息")
    @PostMapping("/getUserCashAccountBaseInfo/{userID}")
    public Object getUserCashAccountBaseInfo(@PathVariable("userID") Long userID){
        return succeed(studentManageService.getStudentAccountBaseInfo(userID));
    }

}
