package com.ym.mec.web.service.impl;

import com.ym.mec.common.dal.BaseDAO;
import com.ym.mec.common.service.impl.BaseServiceImpl;
import com.ym.mec.web.dal.dao.CourseScheduleDao;
import com.ym.mec.web.dal.dto.CourseScheduleDto;
import com.ym.mec.web.dal.dto.TeacherAttendanceDto;
import com.ym.mec.web.dal.entity.CourseSchedule;
import com.ym.mec.web.dal.enums.ParamEnum;
import com.ym.mec.web.service.CourseScheduleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class CourseScheduleServiceImpl extends BaseServiceImpl<Long, CourseSchedule>  implements CourseScheduleService {
	
	@Autowired
	private CourseScheduleDao courseScheduleDao;

	@Override
	public BaseDAO<Long, CourseSchedule> getDAO() {
		return courseScheduleDao;
	}

	@Override
	public TeacherAttendanceDto getCurrentCourseDetail(Long courseID) {
		TeacherAttendanceDto currentCourseDetail = courseScheduleDao.getCurrentCourseDetail(courseID);
		currentCourseDetail.setCurrentTime(new Date());
		currentCourseDetail.setTeacherAttendanceTimeGap(ParamEnum.TEACHER_ATTENDANCE_TIME_GAP);
		return currentCourseDetail;
	}

	@Override
	public String batchAddCourseSchedule(List<CourseSchedule> courseSchedules) {
		String result=checkCourseSchedule(courseSchedules);
		if(result.isEmpty()){
			courseScheduleDao.batchAddCourseSchedules(courseSchedules);
			return result;
		}else{
			return result;
		}
	}

	@Override
	public String batchUpdateCourseSchedule(List<CourseSchedule> courseSchedules, Long musicGroupID) {
		String result=checkCourseSchedule(courseSchedules);
		if(result.isEmpty()){
			courseScheduleDao.deleteCourseSchedulesByMusicGroupID(musicGroupID);
			courseScheduleDao.batchAddCourseSchedules(courseSchedules);
			return result;
		}else{
			return result;
		}
	}

	@Override
	public List<CourseScheduleDto> getCourseSchedulesWithDate(Date classDate) {
		return courseScheduleDao.getCourseSchedulesWithDate(classDate);
	}

	@Override
	public List<Date> getCourseScheduleDateByMonth(Long musicGroupID, Date month) {
		return courseScheduleDao.getCourseScheduleDateByMonth(musicGroupID,month);
	}

	/**
	 * 判断课程安排中是否存在冲突
	 * @param courseSchedules
	 * @return
	 */
	private String checkCourseSchedule(List<CourseSchedule> courseSchedules){
		Map<Date, List<CourseSchedule>> collect = courseSchedules.stream().collect(Collectors.groupingBy(CourseSchedule::getClassDate));
		for(Date keyDate:collect.keySet()){
			List<CourseSchedule> currentCourses=collect.get(keyDate);
			Map<Date, List<CourseSchedule>> collect1 = currentCourses.stream().collect(Collectors.groupingBy(CourseSchedule::getStartClassTime));
			if(currentCourses.size()==collect1.size()){
				continue;
			}else{
				for(Date keyDate2:collect1.keySet()){
					List<CourseSchedule> currentCourses1=collect.get(keyDate2);
					if(currentCourses1.size()>ParamEnum.ONE.getCode()){
						Map<Long, List<CourseSchedule>> collect2 = currentCourses1.stream().collect(
								Collectors.groupingBy(CourseSchedule::getTeacherId));
						for (Long teacherID:collect2.keySet()){
							if(collect2.get(teacherID).size()>ParamEnum.ONE.getCode()){
								return new SimpleDateFormat("yyyy-MM-dd").format(keyDate)+"日的课程安排在教师分配上有冲突!";
							}
						}
						List<Integer> repeatClassGroupIds = currentCourses1.stream().map(CourseSchedule::getClassGroupId).collect(Collectors.toList());
						Integer[] counts=courseScheduleDao.countStudentInClass(repeatClassGroupIds);
						for (Integer i:counts){
							if (i>ParamEnum.ONE.getCode()){
								return new SimpleDateFormat("yyyy-MM-dd").format(keyDate)+"日的课程安排有学生重复!";
							}
						}
					}
				}
			}
		}
		return "";
	}
}